@@ -123,14 +123,14 @@ class Circuit(CircuitBased):
         if ancillae_qubits is not None:
             self.ancillae_qubits = ancillae_qubits
 
-        logger.info(f"Initial Quantum Circuit {name} with {wires} qubits.")
+        logger.debug(f"Initial Quantum Circuit {name} with {wires} qubits.")
         if topology is not None:
             self.topology = topology
-            logger.info(f"The Layout for Quantum Circuit is {self._topology}.")
+            logger.debug(f"The Layout for Quantum Circuit is {self._topology}.")
 
         if fidelity is not None:
             self.fidelity = fidelity
-            logger.info(f"The Fidelity for Quantum Circuit is {self.fidelity}.")
+            logger.debug(f"The Fidelity for Quantum Circuit is {self.fidelity}.")
 
     def __del__(self):
         """ release the memory """
@@ -138,7 +138,7 @@ class Circuit(CircuitBased):
         self._qubits = None
         self.topology = None
         self.fidelity = None
-        logger.info(f"Delete Quantum Circuit {self._name}.")
+        logger.debug(f"Delete Quantum Circuit {self._name}.")
 
     def __or__(self, targets):
         """deal the operator '|'
