@@ -4,7 +4,7 @@
 # @Author  : Han Yu
 # @File    : __init__.py
 
-from .auto_optimization import AutoOptimization
+from .clifford_rz_optimization import CliffordRzOptimization
 from .symbolic_clifford_optimization import SymbolicCliffordOptimization
 from .cnot_ancilla import CnotAncilla
 from .commutative_optimization import CommutativeOptimization
@@ -14,6 +14,4 @@ from .cnot_local_force import (
     CnotStoreForceBfs, CnotStoreForceDepthBfs
 )
 from .cnot_without_ancilla import CnotWithoutAncilla
-from .topological_cnot import TopologicalCnot
-from .topological_cnot_rz import TopologicalCnotRz
 from .template_optimization import TemplateOptimization
