@@ -3,4 +3,4 @@ from .cpu_simulator import CircuitSimulator
 try:
     from .gpu_simulator import ConstantStateVectorSimulator
 except Exception as e:
-    pass
+    raise KeyError(e)
